﻿using System;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;

namespace GpsNose.SDK.Framework.Json
{
    public class DateTimeFormatter : JsonConverter
    {
        public override bool CanConvert(Type objectType)
        {
            bool canConvert =
                objectType == typeof(DateTime) ||
                objectType == typeof(DateTime?);

            return canConvert;
        }


        public override object ReadJson(JsonReader reader, Type objectType, object existingValue, JsonSerializer serializer)
        {
            JToken jt = JToken.ReadFrom(reader);

            // maybe it's recognized already as the old MS unix-format
            if (jt.Type == JTokenType.Date)
                return jt.Value<DateTime>();

            // try to parse from long-ticks
            DateTime dt = DateTime.MinValue;

            switch (jt.Type)
            {
                case JTokenType.Integer:
                    {
                        var ticks = jt.Value<long>();
                        dt = new DateTime(ticks);
                        break;
                    }

                case JTokenType.String:
                    {
                        string json = jt.Value<string>();

                        // try to parse as int
                        long.TryParse(json, out var ticks);

                        // use ticks or try to parse anything else
                        if (ticks != 0)
                            dt = new DateTime(ticks);
                        else
                        {
                            if (!DateTime.TryParse(json, out dt))
                            {
                                // try the old MS-style "Date("
                                var regex = new Regex(@"Date\((\d*)\)");
                                var match = regex.Match(json);
                                if (match.Success)
                                {
                                    string ticksVal = match.Groups[1].Value;
                                    if (long.TryParse(ticksVal, out long unixTicks))
                                    {
                                        var dto = DateTimeOffset.FromUnixTimeMilliseconds(unixTicks);
                                        dt = dto.UtcDateTime;
                                    }
                                }
                            }
                        }

                        break;
                    }

                case JTokenType.Null:
                    {
                        if (objectType == typeof(DateTime?))
                            return null;

                        return DateTime.MinValue;
                    }
            }

            return dt;
        }


        public override void WriteJson(JsonWriter writer, object value, JsonSerializer serializer)
        {
            long ticks = ((DateTime?)value)?.Ticks ?? 0;

            serializer.Serialize(writer, ticks);
        }
    }
}