﻿using System;
using Newtonsoft.Json;
using Newtonsoft.Json.Serialization;

namespace GpsNose.SDK.Framework.Json
{
    public class JsonTool
    {
        public bool IsLongAsString { get; set; } = false;
        public bool IsNullIgnored { get; set; } = true;
        public bool IsDateTimeCustomized { get; set; } = true;
        public bool IsMsDictionaryReadingSupported { get; set; } = true;
        //public PreserverReferencesHandling { get; set; }
        public ReferenceLoopHandling ReferenceLoopHandling { get; set; } = ReferenceLoopHandling.Error;

        public IContractResolver ContractResolver { get; set; } = null;

        public string SerializeToString(object o)
        {
            var set = CreateSettings();

            string s = JsonConvert.SerializeObject(o, set);

            return s;
        }


        public object DeserializeFromString(string json)
        {
            var o = DeserializeFromString(json, typeof(object));

            return o;
        }


        public object DeserializeFromString(string json, Type type)
        {
            if (string.IsNullOrWhiteSpace(json) || json.Trim() == "null")
                return null;

            var set = CreateSettings();
            var o = JsonConvert.DeserializeObject(json, type, set);

            return o;
        }


        public T DeserializeFromString<T>(string json)
        {
            object o = DeserializeFromString(json, typeof(T));

            if (o == null)
                return default(T);

            return (T)o;
        }


        private JsonSerializerSettings CreateSettings()
        {
            var set = new JsonSerializerSettings
            {
                NullValueHandling = IsNullIgnored ? NullValueHandling.Ignore : NullValueHandling.Include,
                ReferenceLoopHandling = ReferenceLoopHandling
            };

            if (IsLongAsString)
                set.Converters.Add(new LongJsonFormatter());

            if (IsDateTimeCustomized)
                set.Converters.Add(new DateTimeFormatter());

            if (IsMsDictionaryReadingSupported)
                set.Converters.Add(new MsDictionaryFormatter());

            if (ContractResolver != null)
                set.ContractResolver = ContractResolver;

            return set;
        }


        public static string QuickJson(object data)
        {
            var ser = new JsonTool
            {
                IsLongAsString = true,
                IsDateTimeCustomized = false,
            };

            string json = ser.SerializeToString(data);

            return json;
        }

    }
}
