﻿using System;
using System.Collections;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;

namespace GpsNose.SDK.Framework.Json
{
    public class MsDictionaryFormatter : JsonConverter
    {
        public override object ReadJson(JsonReader reader, Type objectType, object existingValue, JsonSerializer serializer)
        {
            // create the Dictionary with correct types
            object result = Activator.CreateInstance(objectType);

            if (reader.TokenType == JsonToken.StartArray)
            {
                JArray msArray = (JArray)JToken.ReadFrom(reader);

                if (msArray.Count > 0)
                {
                    var addCall = objectType.GetMethod("Add");

                    foreach (JToken token in msArray)
                    {
                        object key = token["Key"].ToObject(objectType.GenericTypeArguments[0], serializer);
                        object val = token["Value"].ToObject(objectType.GenericTypeArguments[1], serializer);

                        // add the key/val item from the MS-json
                        var par = new[] { key, val };
                        addCall.Invoke(result, par);
                    }
                }
            }
            else
                serializer.Populate(reader, result);

            return result;
        }


        public override bool CanWrite => false;


        public override void WriteJson(JsonWriter writer, object value, JsonSerializer serializer)
        {
            throw new NotImplementedException();
        }


        public override bool CanConvert(Type objectType)
        {
            bool isDictionary = typeof(IDictionary).IsAssignableFrom(objectType);

            return isDictionary;
        }
    }
}
