﻿using System;
using System.IO;
using System.Runtime.CompilerServices;

namespace GpsNose.SDK.Framework.Logging
{
    public static class GnLogger
    {
        public static string FormatMessage(string msg, int lineNumber = 0, string caller = null, string filePath = null) => $"{msg} {filePath} {lineNumber} {caller}";

        public static void Verbose(string msg, [CallerLineNumber] int lineNumber = 0, [CallerMemberName] string caller = null, [CallerFilePath] string filePath = null) => WriteLog(GnLogLevel.Verbose, msg, lineNumber, caller, Path.GetFileName(filePath));
        public static void Info(string msg, [CallerLineNumber] int lineNumber = 0, [CallerMemberName] string caller = null, [CallerFilePath] string filePath = null) => WriteLog(GnLogLevel.Information, msg, lineNumber, caller, Path.GetFileName(filePath));
        public static void Warning(string msg, [CallerLineNumber] int lineNumber = 0, [CallerMemberName] string caller = null, [CallerFilePath] string filePath = null) => WriteLog(GnLogLevel.Warning, msg, lineNumber, caller, filePath);
        public static void Error(string msg, [CallerLineNumber] int lineNumber = 0, [CallerMemberName] string caller = null, [CallerFilePath] string filePath = null) => WriteLog(GnLogLevel.Error, msg, lineNumber, caller, filePath);
        public static void Critical(string msg, [CallerLineNumber] int lineNumber = 0, [CallerMemberName] string caller = null, [CallerFilePath] string filePath = null) => WriteLog(GnLogLevel.Critical, msg, lineNumber, caller, filePath);

        private static void WriteLog(GnLogLevel level, string msg, int linenumber, string caller, string filepath)
        {
            msg = FormatMessage(msg, linenumber, caller, filepath);

            GnLogConfig.Listeners.ForEach(l => l.WriteToLog(level, msg));
        }


        public static void LogException(Exception ex, [CallerLineNumber] int lineNumber = 0, [CallerMemberName] string caller = null, [CallerFilePath] string filePath = null)
        {
            string msg = GetAllMessagesFromException(ex);
            WriteLog(GnLogLevel.Critical, msg, lineNumber, caller, filePath);
        }


        private static string GetAllMessagesFromException(Exception ex, int level = 0)
        {
            string msg = GetMsgFromEx(ex, level == 0);

            if (ex.InnerException != null)
                msg += " ==> " + GetAllMessagesFromException(ex.InnerException, ++level);

            return msg;
        }


        private static string GetMsgFromEx(Exception ex, bool includeStack)
        {
            string msg = $"[{ex.GetType().Name}] {ex.Message}";

            if (includeStack)
                msg += $" - {ex.StackTrace}";

            return msg;
        }
    }
}
