﻿using GpsNose.SDK.Mashup.Api.Modules;
using GpsNose.SDK.Mashup.Framework;

namespace GpsNose.SDK.Mashup.Api
{
    /// <summary>
    /// The main GpsNose API entry point.
    /// </summary>
    /// <remarks>
    /// Can be reused once instantiated.
    /// Use the GnLoginApi() to get the concrete use-case specific APIs.
    /// </remarks>
    /// <example>
    /// var api = new GnApi();
    /// var loginApi = api.GetLoginApi("KEY");
    /// var newsApi = loginApi.GetNewsApi();
    /// var news = newsApi.GetNewsPage();
    /// </example>
    public class GnApi
    {
        internal static string ApiRoot => $"{GnPaths.HomeUrlSslNeeded}/Mashup";

        /// <summary>
        /// Get the GnLoginApi used for mashup-admin calls.
        /// </summary>
        /// <param name="loginId">If provided: any alphanumerical random string, at least 10 chars long.</param>
        /// <param name="langId">The 2-letter lowercase ISO-code for language-specific API results</param>
        public GnLoginApiAdmin GetLoginApiForAdmin(string loginId = null, string langId = null)
        {
            if (string.IsNullOrWhiteSpace(langId))
                langId = GnSettings.CurrentLangId;

            var loginApi = new GnLoginApiAdmin(this, null, loginId, langId);

            return loginApi;
        }


        /// <summary>
        /// The GnLoginApi used for end-user API calls.
        /// </summary>
        /// <param name="appKey">The mashup's appKey</param>
        /// <param name="loginId">If provided: any alphanumerical random string, at least 10 chars long.</param>
        /// <param name="langId">The 2-letter lowercase ISO-code for language-specific API results</param>
        public GnLoginApiEndUser GetLoginApiForEndUser(string appKey, string loginId = null, string langId = null)
        {
            if (string.IsNullOrWhiteSpace(langId))
                langId = GnSettings.CurrentLangId;

            var loginApi = new GnLoginApiEndUser(this, appKey, loginId, langId);

            return loginApi;
        }

    }
}
