﻿using System;
using System.Collections.Generic;
using GpsNose.SDK.Mashup.Framework;
using GpsNose.SDK.Mashup.Model;

namespace GpsNose.SDK.Mashup.Api.Modules
{
    /// <summary>
    /// Community functionality API.
    /// </summary>
    public class GnCommunityApi : GnApiModuleBase
    {
        internal GnCommunityApi(GnLoginApiBase loginApi) : base(loginApi)
        {
        }


        /// <summary>
        /// Page through the members in the creational order.
        /// </summary>
        /// <remarks>
        /// The community's members-paging can be enabled/disabled in the mobile app: long press a community, go to edit details, disable members-paging.
        /// </remarks>
        /// <param name="lastKnownTicks">To start paging, leave out or set to current or future UTC. Later use the last-known ticks from the last page.</param>
        /// <param name="community">Which sub/community to page through. Default: the main web-community.</param>
        /// <param name="pageSize">Page size. Default 12, or [1..20].</param>
        /// <returns>Member names with their creation-ticks.</returns>
        public Dictionary<string, long> GetMembersPage(long lastKnownTicks = GnSettings.FAR_FUTURE_TICKS, string community = null, int? pageSize = null)
        {
            var result = ExecuteCall<Dictionary<string, long>>("PageCommunityMembers", new
            {
                community = community,
                lastKnownTicks = lastKnownTicks,
                pageSize = pageSize
            });

            return result;
        }


        /// <summary>
        /// Get the community details.
        /// </summary>
        /// <param name="community">The sub/community; default is the main web-community, or can be a sub-community like %www.geohamster.com@honolulu</param>
        /// <returns>The community details.</returns>
        public GnCommunity GetCommunity(string community = null)
        {
            var result = ExecuteCall<GnCommunity>("GetCommunity", new
            {
                community = community
            });

            return result;
        }


        public byte[] GenerateQrCodeForCommunityJoin(string community = null)
        {
            var buf = ExecuteCall<byte[]>("GenerateQrCodeForCommunityJoin", new
            {
                community
            }, cacheTtl: TimeSpan.FromDays(1));

            return buf;
        }


        /// <summary>
        /// Sends a nose-mail invitation to a new community member.
        /// </summary>
        /// <param name="toLoginName">To whom to send the invitation.</param>
        /// <param name="community">Which community invite into; default is the main mashup community.</param>
        /// <remarks>Can be used for automatic nose level-up functionality, like "juniors", "seniors", based on your site's business rules.</remarks>
        public void InviteMemberToCommunity(string toLoginName, string community = null)
        {
            ExecuteCall("InviteMemberToCommunity", new
            {
                community,
                toLoginName
            }, cacheTtl: TimeSpan.MaxValue);
        }

    }
}
