﻿using GpsNose.SDK.Mashup.Framework;
using GpsNose.SDK.Mashup.Model;

namespace GpsNose.SDK.Mashup.Api.Modules
{
    /// <summary>
    /// The login-api for the admin-user.
    /// </summary>
    public class GnLoginApiAdmin : GnLoginApiBase
    {
        /// <summary>
        /// Generate the login QR-code for the admin-user.
        /// </summary>
        /// <param name="acls">The ACLs defining which data you will get about the logged-in user.</param>
        /// <returns>The QR-code image, which you must display to your user, to be scanned-in with his GpsNose mobile-app.</returns>
        public byte[] GenerateQrCode(GnMashupLoginAcl acls = GnMashupLoginAcl.None)
        {
            var qrCode = GenerateQrCode(GnSettings.GPSNOSE_COMMUNITY, true, true, acls);

            return qrCode;
        }


        /// <summary>
        /// Gets the GnAdminApi for the admin user.
        /// </summary>
        /// <remarks>
        /// This GnLoginApi instance must be created using <see cref="GnApi.GetLoginApiForAdmin"/> to use this function.
        /// </remarks>
        /// <returns>The GnAdminApi.</returns>
        public GnAdminApi GetAdminApi()
        {
            AssureLoggedInAlready();

            return new GnAdminApi(this);
        }

        internal GnLoginApiAdmin(GnApi api, string appKey, string loginId, string langId) : base(api, appKey, loginId, langId)
        {
        }
    }
}
