﻿using GpsNose.SDK.Mashup.Framework;
using GpsNose.SDK.Mashup.Model;

namespace GpsNose.SDK.Mashup.Api.Modules
{
    /// <summary>
    /// The login-api for the end-user.
    /// </summary>
    public class GnLoginApiEndUser : GnLoginApiBase
    {
        /// <summary>
        /// Generate the login QR-code for the end-user.
        /// </summary>
        /// <param name="mustJoin">If the user must join the target community (it's the one belonging to your mashup's app-key)</param>
        /// <param name="needsActivation">If the user must be activated, i.e. his email is verified already.</param>
        /// <param name="acls">The ACLs defining which data you will get about the logged-in user.</param>
        /// <returns>The QR-code image, which you must display to your user, to be scanned-in with his GpsNose mobile-app.</returns>
        public byte[] GenerateQrCode(bool mustJoin = false, bool needsActivation = false, GnMashupLoginAcl acls = GnMashupLoginAcl.None)
        {
            var qrCode = GenerateQrCode(null, mustJoin, needsActivation, acls);

            return qrCode;
        }


        /// <summary>
        /// Gets the utilities related to mapping.
        /// </summary>
        /// <returns></returns>
        public GnMappingApi GetGnMappingApi()
        {
            return new GnMappingApi(this);
        }


        /// <summary>
        /// Get the GnNewsApi for an end-user.
        /// </summary>
        /// <remarks>Not available for admin-user.</remarks>
        /// <returns>The GnNewsApi.</returns>
        public GnNewsApi GetNewsApi()
        {
            return new GnNewsApi(this);
        }


        /// <summary>
        /// The the GnMailsApi for an end-user or the community-creator.
        /// </summary>
        /// <remarks>
        /// When the calling user is not logged-in, the community-creator is assumed.
        /// Be careful to first test, if you really want to get and use the community-creator's mails ;-)!
        /// </remarks>
        /// <returns>The GnMailsAPi.</returns>
        public GnMailsApi GetMailsApi()
        {
            return new GnMailsApi(this);
        }


        /// <summary>
        /// Get the GnCommentsApi for an end-user.
        /// </summary>
        /// <remarks>Not available for admin-user.</remarks>
        /// <returns>The GnCommentsApi.</returns>
        public GnCommentsApi GetCommentsApi()
        {
            return new GnCommentsApi(this);
        }


        /// <summary>
        /// Get the GnNearbyApi for an end-user.
        /// </summary>
        /// <remarks>Not available for admin-user.</remarks>
        /// <returns>The GnNearbyApi.</returns>
        public GnNearbyApi GetNearbyApi()
        {
            return new GnNearbyApi(this);
        }


        /// <summary>
        /// Get the GnCommunityApi for an end-user.
        /// </summary>
        /// <remarks>Not available for admin-user.</remarks>
        /// <returns>The GnCommunityApi.</returns>
        public GnCommunityApi GetCommunityApi()
        {
            return new GnCommunityApi(this);
        }


        /// <summary>
        /// Get the GnStorageApi for an end-user.
        /// </summary>
        /// <remarks>The user must be logged-in.</remarks>
        /// <returns>The GnStorageApi.</returns>
        public GnStorageApi GetStorageApi()
        {
            return new GnStorageApi(this);
        }


        /// <summary>
        /// Get the GnMashupTokensApi for an end-user.
        /// </summary>
        /// <returns>The GnMashupTokensApi.</returns>
        /// <remarks>Be careful not to publish your app-key, as this API allows the end-user to read the scanned tokens!</remarks>
        public GnMashupTokensApi GetMashupTokensApi()
        {
            return new GnMashupTokensApi(this);
        }


        public GnLoginApiEndUser(GnApi api, string appKey, string loginId, string langId) : base(api, appKey, loginId, langId)
        {
        }
    }
}
