﻿using GpsNose.SDK.Mashup.Framework;

namespace GpsNose.SDK.Mashup.Api.Modules
{
    /// <summary>
    /// Mapping related utilities
    /// </summary>
    public class GnMappingApi : GnApiModuleBase
    {
        public const int MAX_ZOOM = 28;

        internal GnMappingApi(GnLoginApiBase loginApi) : base(loginApi)
        {
        }

        /// <summary>
        /// Gets a rectangular from-to lat/lon from a geo-ip string.
        /// </summary>
        /// <param name="gip">The geo-ip</param>
        /// <returns>The map-rectangle, which the gip describes.</returns>
        public GnMapRectangle GetLatLonRectangleFromGIp(string gip)
        {
            var res = ExecuteCall<GnMapRectangle>("GetLatLonRectangleFromGIp", new
            {
                gip = gip
            });

            return res;
        }


        /// <summary>
        /// Convert the given lat/lon into a geo-ip string.
        /// </summary>
        /// <param name="lat">Latitude for the wanted location.</param>
        /// <param name="lon">Longitude for the wanted location.</param>
        /// <param name="zoom">Zoom level [0..28]</param>
        /// <returns>The geo-ip encoded location with a given zoom.</returns>
        public string GetGipFromLatLon(double lat, double lon, int zoom = MAX_ZOOM)
        {
            var res = ExecuteCall<string>("GetGipFromLatLon", new
            {
                lat = lat,
                lon = lon,
                zoom = zoom
            });

            return res;
        }

    }
}
