﻿using System;
using System.Collections.Generic;
using GpsNose.SDK.Mashup.Model;
using GpsNose.SDK.Mashup.Model.CreatedEntities;

namespace GpsNose.SDK.Mashup.Api.Modules
{
    /// <summary>
    /// Provides access to the real-world data around your end-user, like impressions, Noses, PoIs, Tracks, Events etc.
    /// All the API calls accepts an optional sub-community, or defaults to the one mapped to your app-key.
    /// When an item has a picture, you can get it referring the corresponding URL address using the item's creation-key.
    /// </summary>
    public class GnNearbyApi : GnApiModuleBase
    {
        internal GnNearbyApi(GnLoginApiBase loginApi) : base(loginApi)
        {
        }


        /// <summary>
        /// Return the Noses (other GpsNose users) around.
        /// </summary>
        /// <param name="community"></param>
        /// <returns></returns>
        public List<GnNose> GetNosesAround(string community = null)
        {
            var result = ExecuteCall<List<GnNose>>("GetNosesAround", new
            {
                community = community,
            }, cacheTtl: TimeSpan.MaxValue);

            return result;
        }


        /// <summary>
        /// Return the Impressions (texts or pictures) around.
        /// </summary>
        /// <param name="community"></param>
        /// <returns></returns>
        public List<GnImpression> GetImpressionsAround(string community = null)
        {
            var result = ExecuteCall<List<GnImpression>>("GetImpressionsAround", new
            {
                community = community,
            }, cacheTtl: TimeSpan.MaxValue);

            return result;
        }


        /// <summary>
        /// Return the PoIs (points of interesst) around.
        /// </summary>
        /// <param name="community"></param>
        /// <returns></returns>
        public List<GnPoI> GetPoIsAround(string community = null)
        {
            var result = ExecuteCall<List<GnPoI>>("GetPoIsAround", new
            {
                community = community,
            }, cacheTtl: TimeSpan.MaxValue);

            return result;
        }


        /// <summary>
        /// Return the Events (what is happing where, with voting for date, subscribing etc.) around.
        /// </summary>
        /// <param name="community"></param>
        /// <returns></returns>
        public List<GnEvent> GetEventsAround(string community = null)
        {
            var result = ExecuteCall<List<GnEvent>>("GetEventsAround", new
            {
                community = community,
            }, cacheTtl: TimeSpan.MaxValue);

            return result;
        }


        public List<GnTrack> GetTracksAround(string community = null)
        {
            var result = ExecuteCall<List<GnTrack>>("GetTracksAround", new
            {
                community = community,
            }, cacheTtl: TimeSpan.MaxValue);

            return result;
        }

    }
}
