namespace GpsNose.SDK.Mashup
{
    /// <summary>
    /// Used for local app/web configuration.
    /// </summary>
    public class GnLocalSettings
    {
        /// <summary>
        /// Overwrite from your app-start with your app-key.
        /// </summary>
        public static string AppKey { get; set; } = "YOUR-APP-KEY";

        /// <summary>
        /// Overwrite from your app-start with your main web-community.
        /// </summary>
        /// <example>
        /// %www.geohamster.com
        /// </example>
        public static string Community { get; set; } = "%www.YOUR-WEB-DOMAIN.com";

        /// <summary>
        /// Overwrite from your app-start with your local-web GpsNose images path.
        /// </summary>
        public static string GnImagesPath { get; set; } = "/Content/GpsNose/Images";

        /// <summary>
        /// Set to the language-id your app/thread runs in, like 'en' for example
        /// </summary>
        /// <example>
        /// en, de, sk..
        /// </example>
        public static string LangId { get; set; }

        /// <summary>
        /// Returns the item's placeholder image path for things like img's onerror usage.
        /// </summary>
        /// <remarks>
        /// When an item's image doesn't exist, you can set the img's error-handler to set this placeholder instead.
        /// </remarks>
        /// <example>
        /// &lt;img src="..." onerror="this.src='GetEmptyImagePath(...)'" /&gt;
        /// </example>
        /// <param name="itemType">Which item item.</param>
        /// <param name="itemKey">Which item's unique-key.</param>
        /// <returns>The placeholder-image path and name.</returns>
        public static string GetEmptyImagePath(GnUrlItemType itemType, string itemKey = null)
        {
            string fileName = "EmptyImage.png";

            switch (itemType)
            {
                case GnUrlItemType.Community:
                    {
                        fileName = "EmptyCommunity.png";
                        break;
                    }

                case GnUrlItemType.Nose:
                    {
                        fileName = "EmptyUser.png";
                        break;
                    }

                case GnUrlItemType.Track:
                    {
                        fileName = "EmptyMap.png";
                        break;
                    };
            }

            return $"{GnImagesPath}/{fileName}";
        }

    }
}
