﻿using System;
using System.Web;
using System.Web.Security;
using GpsNose.SDK.Framework.Json;
using GpsNose.SDK.Mashup;
using GpsNose.SDK.Mashup.Api;

namespace GpsNose.SDK.Web.NetFramework.Login
{
    public class GnAuthenticationModule : IHttpModule
    {
        public const string DIRECT_LOGIN_PARAM_NAME = "gnlid";


        public void Init(HttpApplication context)
        {
            context.AuthenticateRequest += GnContextOnAuthenticateRequest;
            context.PostAuthenticateRequest += GnContext_PostAuthenticateRequest;
        }


        private void GnContextOnAuthenticateRequest(object sender, EventArgs e)
        {
            if (!(sender is HttpApplication app))
                return;

            // cookie-based
            HttpCookie loginCookie = app.Request.Cookies[DIRECT_LOGIN_PARAM_NAME];
            if (loginCookie != null && TryLogin(loginCookie.Value))
            {
                // remove the gn-direct-login cookie
                loginCookie.Expires = DateTime.Now.AddDays(-1d);
                app.Response.Cookies.Add(loginCookie);
                return;
            }

            // url-based
            string loginParam = app.Request.QueryString[DIRECT_LOGIN_PARAM_NAME];
            if (!string.IsNullOrEmpty(loginParam))
                TryLogin(loginParam);

            return;

            bool TryLogin(string loginId)
            {
                var api = new GnApi();
                var gnLogin = api.GetLoginApiForEndUser(GnLocalSettings.AppKey, loginId).GetVerified();

                if (gnLogin != null)
                {
                    var authCookie = GnAuthentication.GenerateAuthenticationCookie(gnLogin, loginId, 30, false);
                    app.Response.Cookies.Add(authCookie);

                    return true;
                }

                return false;
            }
        }


        private void GnContext_PostAuthenticateRequest(object sender, EventArgs e)
        {
            var app = sender as HttpApplication;

            HttpCookie authCookie = app?.Request.Cookies[FormsAuthentication.FormsCookieName];
            if (authCookie != null)
            {
                try
                {
                    FormsAuthenticationTicket authTicket = FormsAuthentication.Decrypt(authCookie.Value);

                    if (authTicket != null)
                    {
                        // GN-based or fallback/standard?
                        if (!string.IsNullOrWhiteSpace(authTicket.UserData))
                        {
                            // ok, the user comes from GN
                            var gnAuthData = new JsonTool().DeserializeFromString<GnAuthenticationData>(authTicket.UserData);
                            HttpContext.Current.User = gnAuthData;
                        }
                        else
                        {
                            // the user was set by another mechanism, like standard web-forms
                            var identity = new FormsIdentity(authTicket);
                            var rolePrincipal = new RolePrincipal(identity);

                            HttpContext.Current.User = rolePrincipal;
                        }
                    }
                }
                catch (Exception ex)
                {
                    // invalid auth-cookie or something..
                    FormsAuthentication.SignOut();
                }
            }
        }


        public void Dispose()
        {
        }
    }
}